# korapay-client

[![Total Downloads](https://static.pepy.tech/badge/korapay-client)](https://pepy.tech/project/korapay-client)
[![Monthly Downloads](https://static.pepy.tech/badge/korapay-client/month)](https://pepy.tech/project/korapay-client)
[![Weekly Downloads](https://static.pepy.tech/badge/korapay-client/week)](https://pepy.tech/project/korapay-client)

A developer-friendly python client SDK for [Korapay](https://www.korahq.com/)

## Documentation
See [Documentation](https://gray-adeyi.github.io/korapay_client/) for more on this package.